@@ -5,7 +5,7 @@
  * SPDX-License-Identifier: MIT
  *
  * @file zes_ddi.h
- * @version v1.4-r1.4.8
+ * @version v1.6-r1.6.10
  *
  */
 #ifndef _ZES_DDI_H
@@ -20,37 +20,20 @@ extern "C" {
 #endif
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Function-pointer for zesDriverEventListen 
-typedef ze_result_t (ZE_APICALL *zes_pfnDriverEventListen_t)(
-    ze_driver_handle_t,
-    uint32_t,
-    uint32_t,
-    zes_device_handle_t*,
-    uint32_t*,
-    zes_event_type_flags_t*
+/// @brief Function-pointer for zesInit 
+typedef ze_result_t (ZE_APICALL *zes_pfnInit_t)(
+    zes_init_flags_t
     );
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Function-pointer for zesDriverEventListenEx 
-typedef ze_result_t (ZE_APICALL *zes_pfnDriverEventListenEx_t)(
-    ze_driver_handle_t,
-    uint64_t,
-    uint32_t,
-    zes_device_handle_t*,
-    uint32_t*,
-    zes_event_type_flags_t*
-    );
-
-///////////////////////////////////////////////////////////////////////////////
-/// @brief Table of Driver functions pointers
-typedef struct _zes_driver_dditable_t
+/// @brief Table of Global functions pointers
+typedef struct _zes_global_dditable_t
 {
-    zes_pfnDriverEventListen_t                                  pfnEventListen;
-    zes_pfnDriverEventListenEx_t                                pfnEventListenEx;
-} zes_driver_dditable_t;
+    zes_pfnInit_t                                               pfnInit;
+} zes_global_dditable_t;
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Exported function for filling application's Driver table
+/// @brief Exported function for filling application's Global table
 ///        with current process' addresses
 ///
 /// @returns
@@ -59,16 +42,16 @@ typedef struct _zes_driver_dditable_t
 ///     - ::ZE_RESULT_ERROR_INVALID_NULL_POINTER
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
-zesGetDriverProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_driver_dditable_t* pDdiTable                ///< [in,out] pointer to table of DDI function pointers
+zesGetGlobalProcAddrTable(
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_global_dditable_t* pDdiTable                                        ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Function-pointer for zesGetDriverProcAddrTable
-typedef ze_result_t (ZE_APICALL *zes_pfnGetDriverProcAddrTable_t)(
+/// @brief Function-pointer for zesGetGlobalProcAddrTable
+typedef ze_result_t (ZE_APICALL *zes_pfnGetGlobalProcAddrTable_t)(
     ze_api_version_t,
-    zes_driver_dditable_t*
+    zes_global_dditable_t*
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -292,6 +275,61 @@ typedef ze_result_t (ZE_APICALL *zes_pfnDeviceSetEccState_t)(
     zes_device_ecc_properties_t*
     );
 
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesDeviceGet 
+typedef ze_result_t (ZE_APICALL *zes_pfnDeviceGet_t)(
+    zes_driver_handle_t,
+    uint32_t*,
+    zes_device_handle_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesDeviceSetOverclockWaiver 
+typedef ze_result_t (ZE_APICALL *zes_pfnDeviceSetOverclockWaiver_t)(
+    zes_device_handle_t
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesDeviceGetOverclockDomains 
+typedef ze_result_t (ZE_APICALL *zes_pfnDeviceGetOverclockDomains_t)(
+    zes_device_handle_t,
+    uint32_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesDeviceGetOverclockControls 
+typedef ze_result_t (ZE_APICALL *zes_pfnDeviceGetOverclockControls_t)(
+    zes_device_handle_t,
+    zes_overclock_domain_t,
+    uint32_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesDeviceResetOverclockSettings 
+typedef ze_result_t (ZE_APICALL *zes_pfnDeviceResetOverclockSettings_t)(
+    zes_device_handle_t,
+    ze_bool_t
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesDeviceReadOverclockState 
+typedef ze_result_t (ZE_APICALL *zes_pfnDeviceReadOverclockState_t)(
+    zes_device_handle_t,
+    zes_overclock_mode_t*,
+    ze_bool_t*,
+    ze_bool_t*,
+    zes_pending_action_t*,
+    ze_bool_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesDeviceEnumOverclockDomains 
+typedef ze_result_t (ZE_APICALL *zes_pfnDeviceEnumOverclockDomains_t)(
+    zes_device_handle_t,
+    uint32_t*,
+    zes_overclock_handle_t*
+    );
+
 ///////////////////////////////////////////////////////////////////////////////
 /// @brief Table of Device functions pointers
 typedef struct _zes_device_dditable_t
@@ -325,6 +363,13 @@ typedef struct _zes_device_dditable_t
     zes_pfnDeviceEccConfigurable_t                              pfnEccConfigurable;
     zes_pfnDeviceGetEccState_t                                  pfnGetEccState;
     zes_pfnDeviceSetEccState_t                                  pfnSetEccState;
+    zes_pfnDeviceGet_t                                          pfnGet;
+    zes_pfnDeviceSetOverclockWaiver_t                           pfnSetOverclockWaiver;
+    zes_pfnDeviceGetOverclockDomains_t                          pfnGetOverclockDomains;
+    zes_pfnDeviceGetOverclockControls_t                         pfnGetOverclockControls;
+    zes_pfnDeviceResetOverclockSettings_t                       pfnResetOverclockSettings;
+    zes_pfnDeviceReadOverclockState_t                           pfnReadOverclockState;
+    zes_pfnDeviceEnumOverclockDomains_t                         pfnEnumOverclockDomains;
 } zes_device_dditable_t;
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -338,8 +383,8 @@ typedef struct _zes_device_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetDeviceProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_device_dditable_t* pDdiTable                ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_device_dditable_t* pDdiTable                                        ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -349,6 +394,178 @@ typedef ze_result_t (ZE_APICALL *zes_pfnGetDeviceProcAddrTable_t)(
     zes_device_dditable_t*
     );
 
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesDriverEventListen 
+typedef ze_result_t (ZE_APICALL *zes_pfnDriverEventListen_t)(
+    ze_driver_handle_t,
+    uint32_t,
+    uint32_t,
+    zes_device_handle_t*,
+    uint32_t*,
+    zes_event_type_flags_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesDriverEventListenEx 
+typedef ze_result_t (ZE_APICALL *zes_pfnDriverEventListenEx_t)(
+    ze_driver_handle_t,
+    uint64_t,
+    uint32_t,
+    zes_device_handle_t*,
+    uint32_t*,
+    zes_event_type_flags_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesDriverGet 
+typedef ze_result_t (ZE_APICALL *zes_pfnDriverGet_t)(
+    uint32_t*,
+    zes_driver_handle_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Table of Driver functions pointers
+typedef struct _zes_driver_dditable_t
+{
+    zes_pfnDriverEventListen_t                                  pfnEventListen;
+    zes_pfnDriverEventListenEx_t                                pfnEventListenEx;
+    zes_pfnDriverGet_t                                          pfnGet;
+} zes_driver_dditable_t;
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Exported function for filling application's Driver table
+///        with current process' addresses
+///
+/// @returns
+///     - ::ZE_RESULT_SUCCESS
+///     - ::ZE_RESULT_ERROR_UNINITIALIZED
+///     - ::ZE_RESULT_ERROR_INVALID_NULL_POINTER
+///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
+ZE_DLLEXPORT ze_result_t ZE_APICALL
+zesGetDriverProcAddrTable(
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_driver_dditable_t* pDdiTable                                        ///< [in,out] pointer to table of DDI function pointers
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesGetDriverProcAddrTable
+typedef ze_result_t (ZE_APICALL *zes_pfnGetDriverProcAddrTable_t)(
+    ze_api_version_t,
+    zes_driver_dditable_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesOverclockGetDomainProperties 
+typedef ze_result_t (ZE_APICALL *zes_pfnOverclockGetDomainProperties_t)(
+    zes_overclock_handle_t,
+    zes_overclock_properties_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesOverclockGetDomainVFProperties 
+typedef ze_result_t (ZE_APICALL *zes_pfnOverclockGetDomainVFProperties_t)(
+    zes_overclock_handle_t,
+    zes_vf_property_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesOverclockGetDomainControlProperties 
+typedef ze_result_t (ZE_APICALL *zes_pfnOverclockGetDomainControlProperties_t)(
+    zes_overclock_handle_t,
+    zes_overclock_control_t,
+    zes_control_property_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesOverclockGetControlCurrentValue 
+typedef ze_result_t (ZE_APICALL *zes_pfnOverclockGetControlCurrentValue_t)(
+    zes_overclock_handle_t,
+    zes_overclock_control_t,
+    double*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesOverclockGetControlPendingValue 
+typedef ze_result_t (ZE_APICALL *zes_pfnOverclockGetControlPendingValue_t)(
+    zes_overclock_handle_t,
+    zes_overclock_control_t,
+    double*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesOverclockSetControlUserValue 
+typedef ze_result_t (ZE_APICALL *zes_pfnOverclockSetControlUserValue_t)(
+    zes_overclock_handle_t,
+    zes_overclock_control_t,
+    double,
+    zes_pending_action_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesOverclockGetControlState 
+typedef ze_result_t (ZE_APICALL *zes_pfnOverclockGetControlState_t)(
+    zes_overclock_handle_t,
+    zes_overclock_control_t,
+    zes_control_state_t*,
+    zes_pending_action_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesOverclockGetVFPointValues 
+typedef ze_result_t (ZE_APICALL *zes_pfnOverclockGetVFPointValues_t)(
+    zes_overclock_handle_t,
+    zes_vf_type_t,
+    zes_vf_array_type_t,
+    uint32_t,
+    uint32_t*
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesOverclockSetVFPointValues 
+typedef ze_result_t (ZE_APICALL *zes_pfnOverclockSetVFPointValues_t)(
+    zes_overclock_handle_t,
+    zes_vf_type_t,
+    uint32_t,
+    uint32_t
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Table of Overclock functions pointers
+typedef struct _zes_overclock_dditable_t
+{
+    zes_pfnOverclockGetDomainProperties_t                       pfnGetDomainProperties;
+    zes_pfnOverclockGetDomainVFProperties_t                     pfnGetDomainVFProperties;
+    zes_pfnOverclockGetDomainControlProperties_t                pfnGetDomainControlProperties;
+    zes_pfnOverclockGetControlCurrentValue_t                    pfnGetControlCurrentValue;
+    zes_pfnOverclockGetControlPendingValue_t                    pfnGetControlPendingValue;
+    zes_pfnOverclockSetControlUserValue_t                       pfnSetControlUserValue;
+    zes_pfnOverclockGetControlState_t                           pfnGetControlState;
+    zes_pfnOverclockGetVFPointValues_t                          pfnGetVFPointValues;
+    zes_pfnOverclockSetVFPointValues_t                          pfnSetVFPointValues;
+} zes_overclock_dditable_t;
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Exported function for filling application's Overclock table
+///        with current process' addresses
+///
+/// @returns
+///     - ::ZE_RESULT_SUCCESS
+///     - ::ZE_RESULT_ERROR_UNINITIALIZED
+///     - ::ZE_RESULT_ERROR_INVALID_NULL_POINTER
+///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
+ZE_DLLEXPORT ze_result_t ZE_APICALL
+zesGetOverclockProcAddrTable(
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_overclock_dditable_t* pDdiTable                                     ///< [in,out] pointer to table of DDI function pointers
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zesGetOverclockProcAddrTable
+typedef ze_result_t (ZE_APICALL *zes_pfnGetOverclockProcAddrTable_t)(
+    ze_api_version_t,
+    zes_overclock_dditable_t*
+    );
+
 ///////////////////////////////////////////////////////////////////////////////
 /// @brief Function-pointer for zesSchedulerGetProperties 
 typedef ze_result_t (ZE_APICALL *zes_pfnSchedulerGetProperties_t)(
@@ -434,8 +651,8 @@ typedef struct _zes_scheduler_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetSchedulerProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_scheduler_dditable_t* pDdiTable             ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_scheduler_dditable_t* pDdiTable                                     ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -486,8 +703,8 @@ typedef struct _zes_performance_factor_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetPerformanceFactorProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_performance_factor_dditable_t* pDdiTable    ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_performance_factor_dditable_t* pDdiTable                            ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -584,8 +801,8 @@ typedef struct _zes_power_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetPowerProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_power_dditable_t* pDdiTable                 ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_power_dditable_t* pDdiTable                                         ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -751,8 +968,8 @@ typedef struct _zes_frequency_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetFrequencyProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_frequency_dditable_t* pDdiTable             ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_frequency_dditable_t* pDdiTable                                     ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -795,8 +1012,8 @@ typedef struct _zes_engine_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetEngineProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_engine_dditable_t* pDdiTable                ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_engine_dditable_t* pDdiTable                                        ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -847,8 +1064,8 @@ typedef struct _zes_standby_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetStandbyProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_standby_dditable_t* pDdiTable               ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_standby_dditable_t* pDdiTable                                       ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -892,8 +1109,8 @@ typedef struct _zes_firmware_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetFirmwareProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_firmware_dditable_t* pDdiTable              ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_firmware_dditable_t* pDdiTable                                      ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -944,8 +1161,8 @@ typedef struct _zes_memory_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetMemoryProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_memory_dditable_t* pDdiTable                ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_memory_dditable_t* pDdiTable                                        ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -1020,8 +1237,8 @@ typedef struct _zes_fabric_port_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetFabricPortProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_fabric_port_dditable_t* pDdiTable           ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_fabric_port_dditable_t* pDdiTable                                   ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -1080,8 +1297,8 @@ typedef struct _zes_temperature_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetTemperatureProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_temperature_dditable_t* pDdiTable           ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_temperature_dditable_t* pDdiTable                                   ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -1124,8 +1341,8 @@ typedef struct _zes_psu_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetPsuProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_psu_dditable_t* pDdiTable                   ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_psu_dditable_t* pDdiTable                                           ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -1200,8 +1417,8 @@ typedef struct _zes_fan_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetFanProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_fan_dditable_t* pDdiTable                   ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_fan_dditable_t* pDdiTable                                           ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -1260,8 +1477,8 @@ typedef struct _zes_led_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetLedProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_led_dditable_t* pDdiTable                   ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_led_dditable_t* pDdiTable                                           ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -1321,8 +1538,8 @@ typedef struct _zes_ras_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetRasProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_ras_dditable_t* pDdiTable                   ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_ras_dditable_t* pDdiTable                                           ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -1376,8 +1593,8 @@ typedef struct _zes_diagnostics_dditable_t
 ///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
 ZE_DLLEXPORT ze_result_t ZE_APICALL
 zesGetDiagnosticsProcAddrTable(
-    ze_api_version_t version,                       ///< [in] API version requested
-    zes_diagnostics_dditable_t* pDdiTable           ///< [in,out] pointer to table of DDI function pointers
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zes_diagnostics_dditable_t* pDdiTable                                   ///< [in,out] pointer to table of DDI function pointers
     );
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -1391,8 +1608,10 @@ typedef ze_result_t (ZE_APICALL *zes_pfnGetDiagnosticsProcAddrTable_t)(
 /// @brief Container for all DDI tables
 typedef struct _zes_dditable_t
 {
-    zes_driver_dditable_t               Driver;
+    zes_global_dditable_t               Global;
     zes_device_dditable_t               Device;
+    zes_driver_dditable_t               Driver;
+    zes_overclock_dditable_t            Overclock;
     zes_scheduler_dditable_t            Scheduler;
     zes_performance_factor_dditable_t   PerformanceFactor;
     zes_power_dditable_t                Power;
