@@ -120,8 +120,8 @@ namespace driver
         uint64_t timeout,                               ///< [in] if non-zero, then indicates the maximum time (in milliseconds) to
                                                         ///< yield before returning ::ZE_RESULT_SUCCESS or ::ZE_RESULT_NOT_READY;
                                                         ///< if zero, then immediately returns the status of the event;
-                                                        ///< if UINT64_MAX, then function will not return until complete or device
-                                                        ///< is lost.
+                                                        ///< if `UINT64_MAX`, then function will not return until complete or
+                                                        ///< device is lost.
                                                         ///< Due to external dependencies, timeout may be rounded to the closest
                                                         ///< value allowed by the accuracy of those dependencies.
         zet_debug_event_t* event                        ///< [in,out] a pointer to a ::zet_debug_event_t.
@@ -302,6 +302,40 @@ namespace driver
         return result;
     }
 
+    ///////////////////////////////////////////////////////////////////////////////
+    /// @brief Intercept function for zetDebugGetThreadRegisterSetProperties
+    __zedlllocal ze_result_t ZE_APICALL
+    zetDebugGetThreadRegisterSetProperties(
+        zet_debug_session_handle_t hDebug,              ///< [in] debug session handle
+        ze_device_thread_t thread,                      ///< [in] the thread identifier specifying a single stopped thread
+        uint32_t* pCount,                               ///< [in,out] pointer to the number of register set properties.
+                                                        ///< if count is zero, then the driver shall update the value with the
+                                                        ///< total number of register set properties available.
+                                                        ///< if count is greater than the number of register set properties
+                                                        ///< available, then the driver shall update the value with the correct
+                                                        ///< number of registry set properties available.
+        zet_debug_regset_properties_t* pRegisterSetProperties   ///< [in,out][optional][range(0, *pCount)] array of query results for
+                                                        ///< register set properties.
+                                                        ///< if count is less than the number of register set properties available,
+                                                        ///< then driver shall only retrieve that number of register set properties.
+        )
+    {
+        ze_result_t result = ZE_RESULT_SUCCESS;
+
+        // if the driver has created a custom function, then call it instead of using the generic path
+        auto pfnGetThreadRegisterSetProperties = context.zetDdiTable.Debug.pfnGetThreadRegisterSetProperties;
+        if( nullptr != pfnGetThreadRegisterSetProperties )
+        {
+            result = pfnGetThreadRegisterSetProperties( hDebug, thread, pCount, pRegisterSetProperties );
+        }
+        else
+        {
+            // generic implementation
+        }
+
+        return result;
+    }
+
     ///////////////////////////////////////////////////////////////////////////////
     /// @brief Intercept function for zetDebugReadRegisters
     __zedlllocal ze_result_t ZE_APICALL
@@ -310,9 +344,11 @@ namespace driver
         ze_device_thread_t thread,                      ///< [in] the thread identifier
         uint32_t type,                                  ///< [in] register set type
         uint32_t start,                                 ///< [in] the starting offset into the register state area; must be less
-                                                        ///< than ::zet_debug_regset_properties_t.count for the type
-        uint32_t count,                                 ///< [in] the number of registers to read; start+count must be <=
-                                                        ///< zet_debug_register_group_properties_t.count for the type
+                                                        ///< than the `count` member of ::zet_debug_regset_properties_t for the
+                                                        ///< type
+        uint32_t count,                                 ///< [in] the number of registers to read; start+count must be less than or
+                                                        ///< equal to the `count` member of ::zet_debug_register_group_properties_t
+                                                        ///< for the type
         void* pRegisterValues                           ///< [in,out][optional][range(0, count)] buffer of register values
         )
     {
@@ -340,9 +376,11 @@ namespace driver
         ze_device_thread_t thread,                      ///< [in] the thread identifier
         uint32_t type,                                  ///< [in] register set type
         uint32_t start,                                 ///< [in] the starting offset into the register state area; must be less
-                                                        ///< than ::zet_debug_regset_properties_t.count for the type
-        uint32_t count,                                 ///< [in] the number of registers to write; start+count must be <=
-                                                        ///< zet_debug_register_group_properties_t.count for the type
+                                                        ///< than the `count` member of ::zet_debug_regset_properties_t for the
+                                                        ///< type
+        uint32_t count,                                 ///< [in] the number of registers to write; start+count must be less than
+                                                        ///< or equal to the `count` member of
+                                                        ///< ::zet_debug_register_group_properties_t for the type
         void* pRegisterValues                           ///< [in,out][optional][range(0, count)] buffer of register values
         )
     {
@@ -629,7 +667,7 @@ namespace driver
     zetMetricStreamerReadData(
         zet_metric_streamer_handle_t hMetricStreamer,   ///< [in] handle of the metric streamer
         uint32_t maxReportCount,                        ///< [in] the maximum number of reports the application wants to receive.
-                                                        ///< if UINT32_MAX, then function will retrieve all reports available
+                                                        ///< if `UINT32_MAX`, then function will retrieve all reports available
         size_t* pRawDataSize,                           ///< [in,out] pointer to size in bytes of raw data requested to read.
                                                         ///< if size is zero, then the driver will update the value with the total
                                                         ///< size in bytes needed for all reports available.
@@ -1082,6 +1120,109 @@ namespace driver
         return result;
     }
 
+    ///////////////////////////////////////////////////////////////////////////////
+    /// @brief Intercept function for zetMetricGroupGetGlobalTimestampsExp
+    __zedlllocal ze_result_t ZE_APICALL
+    zetMetricGroupGetGlobalTimestampsExp(
+        zet_metric_group_handle_t hMetricGroup,         ///< [in] handle of the metric group
+        ze_bool_t synchronizedWithHost,                 ///< [in] Returns the timestamps synchronized to the host or the device.
+        uint64_t* globalTimestamp,                      ///< [out] Device timestamp.
+        uint64_t* metricTimestamp                       ///< [out] Metric timestamp.
+        )
+    {
+        ze_result_t result = ZE_RESULT_SUCCESS;
+
+        // if the driver has created a custom function, then call it instead of using the generic path
+        auto pfnGetGlobalTimestampsExp = context.zetDdiTable.MetricGroupExp.pfnGetGlobalTimestampsExp;
+        if( nullptr != pfnGetGlobalTimestampsExp )
+        {
+            result = pfnGetGlobalTimestampsExp( hMetricGroup, synchronizedWithHost, globalTimestamp, metricTimestamp );
+        }
+        else
+        {
+            // generic implementation
+        }
+
+        return result;
+    }
+
+    ///////////////////////////////////////////////////////////////////////////////
+    /// @brief Intercept function for zetMetricGroupGetExportDataExp
+    __zedlllocal ze_result_t ZE_APICALL
+    zetMetricGroupGetExportDataExp(
+        zet_metric_group_handle_t hMetricGroup,         ///< [in] handle of the metric group
+        const uint8_t* pRawData,                        ///< [in] buffer of raw data
+        size_t rawDataSize,                             ///< [in] size in bytes of raw data buffer
+        size_t* pExportDataSize,                        ///< [in,out] size in bytes of export data buffer
+                                                        ///< if size is zero, then the driver shall update the value with the
+                                                        ///< number of bytes necessary to store the exported data.
+                                                        ///< if size is greater than required, then the driver shall update the
+                                                        ///< value with the actual number of bytes necessary to store the exported data.
+        uint8_t * pExportData                           ///< [in,out][optional][range(0, *pExportDataSize)] buffer of exported data.
+        )
+    {
+        ze_result_t result = ZE_RESULT_SUCCESS;
+
+        // if the driver has created a custom function, then call it instead of using the generic path
+        auto pfnGetExportDataExp = context.zetDdiTable.MetricGroupExp.pfnGetExportDataExp;
+        if( nullptr != pfnGetExportDataExp )
+        {
+            result = pfnGetExportDataExp( hMetricGroup, pRawData, rawDataSize, pExportDataSize, pExportData );
+        }
+        else
+        {
+            // generic implementation
+        }
+
+        return result;
+    }
+
+    ///////////////////////////////////////////////////////////////////////////////
+    /// @brief Intercept function for zetMetricGroupCalculateMetricExportDataExp
+    __zedlllocal ze_result_t ZE_APICALL
+    zetMetricGroupCalculateMetricExportDataExp(
+        ze_driver_handle_t hDriver,                     ///< [in] handle of the driver instance
+        zet_metric_group_calculation_type_t type,       ///< [in] calculation type to be applied on raw data
+        size_t exportDataSize,                          ///< [in] size in bytes of exported data buffer
+        const uint8_t* pExportData,                     ///< [in][range(0, exportDataSize)] buffer of exported data to calculate
+        zet_metric_calculate_exp_desc_t* pCalculateDescriptor,  ///< [in] descriptor specifying calculation specific parameters
+        uint32_t* pSetCount,                            ///< [in,out] pointer to number of metric sets.
+                                                        ///< if count is zero, then the driver shall update the value with the
+                                                        ///< total number of metric sets to be calculated.
+                                                        ///< if count is greater than the number available in the raw data buffer,
+                                                        ///< then the driver shall update the value with the actual number of
+                                                        ///< metric sets to be calculated.
+        uint32_t* pTotalMetricValueCount,               ///< [in,out] pointer to number of the total number of metric values
+                                                        ///< calculated, for all metric sets.
+                                                        ///< if count is zero, then the driver shall update the value with the
+                                                        ///< total number of metric values to be calculated.
+                                                        ///< if count is greater than the number available in the raw data buffer,
+                                                        ///< then the driver shall update the value with the actual number of
+                                                        ///< metric values to be calculated.
+        uint32_t* pMetricCounts,                        ///< [in,out][optional][range(0, *pSetCount)] buffer of metric counts per
+                                                        ///< metric set.
+        zet_typed_value_t* pMetricValues                ///< [in,out][optional][range(0, *pTotalMetricValueCount)] buffer of
+                                                        ///< calculated metrics.
+                                                        ///< if count is less than the number available in the raw data buffer,
+                                                        ///< then driver shall only calculate that number of metric values.
+        )
+    {
+        ze_result_t result = ZE_RESULT_SUCCESS;
+
+        // if the driver has created a custom function, then call it instead of using the generic path
+        auto pfnCalculateMetricExportDataExp = context.zetDdiTable.MetricGroupExp.pfnCalculateMetricExportDataExp;
+        if( nullptr != pfnCalculateMetricExportDataExp )
+        {
+            result = pfnCalculateMetricExportDataExp( hDriver, type, exportDataSize, pExportData, pCalculateDescriptor, pSetCount, pTotalMetricValueCount, pMetricCounts, pMetricValues );
+        }
+        else
+        {
+            // generic implementation
+        }
+
+        return result;
+    }
+
 } // namespace driver
 
 #if defined(__cplusplus)
@@ -1273,6 +1414,8 @@ zetGetDebugProcAddrTable(
 
     pDdiTable->pfnWriteRegisters                         = driver::zetDebugWriteRegisters;
 
+    pDdiTable->pfnGetThreadRegisterSetProperties         = driver::zetDebugGetThreadRegisterSetProperties;
+
     return result;
 }
 
@@ -1360,6 +1503,12 @@ zetGetMetricGroupExpProcAddrTable(
 
     pDdiTable->pfnCalculateMultipleMetricValuesExp       = driver::zetMetricGroupCalculateMultipleMetricValuesExp;
 
+    pDdiTable->pfnGetGlobalTimestampsExp                 = driver::zetMetricGroupGetGlobalTimestampsExp;
+
+    pDdiTable->pfnGetExportDataExp                       = driver::zetMetricGroupGetExportDataExp;
+
+    pDdiTable->pfnCalculateMetricExportDataExp           = driver::zetMetricGroupCalculateMetricExportDataExp;
+
     return result;
 }
 
