@@ -35,7 +35,7 @@ namespace ze_lib
 
         std::once_flag initOnce;
 
-        ze_result_t Init(ze_init_flags_t flags);
+        ze_result_t Init(ze_init_flags_t flags, bool sysmanOnly);
 
         ze_result_t zeInit();
         ze_dditable_t   zeDdiTable = {};
@@ -51,8 +51,10 @@ namespace ze_lib
 
         HMODULE tracing_lib = nullptr;
         bool isInitialized = false;
+        bool inTeardown = false;
     };
 
     extern context_t *context;
+    extern bool destruction;
 
 } // namespace ze_lib
